Player Class (pysqueezecenter.player.Player)
============================================

The Player class allows individual control of any Logitech SqueezeCenter compatible
devices that are connected and registered with the SqueezeCenter server.

Any function calls made by the Player are communicated to the SqueezeCenter Telnet server
via the parent Server (pysqueezecenter.server.Server) class.

.. autoclass:: pysqueezecenter.player.Player
   :members:
   :undoc-members:

